@@ -1,14 +1,15 @@
 #include "export.h"
 #include <xs/Ref.h>
 #include <xs/Array.h>
+#include <panda/optional.h>
 
 namespace xs { namespace exp {
 
 using panda::string;
 using panda::string_view;
 
-static thread_local Hash  clists;
-static thread_local Stash self_stash;
+static thread_local panda::optional<Hash>  clists;
+static thread_local panda::optional<Stash> self_stash;
 
 static bool _init () {
     xs::at_perl_destroy([]{
@@ -23,7 +24,7 @@ static void throw_noname (Stash s) { throw std::logic_error(string("Export::XS:
 
 Array constants_list (const Stash& stash) {
     if (!clists) clists = Hash::create();
-    auto clist = clists[stash.name()];
+    auto clist = (*clists)[stash.name()];
     if (!clist.defined()) clist = Ref::create(Array::create());
     return Array(clist);
 }
@@ -85,7 +86,7 @@ void export_constants (const Stash& from, Stash to) {
 
 void autoexport (Stash stash) {
     if (!self_stash) self_stash = Stash("Export::XS", GV_ADD);
-    auto gv = self_stash["import"];
+    auto gv = (*self_stash)["import"];
     auto dsub = stash.sub("import");
     if (dsub && dsub != gv.sub() && (!dsub.stash() || dsub.stash().name() != "UNIVERSAL")) {
         throw std::logic_error(string("Export::XS: can't make autoexport for stash '") + stash.name() + "' - you already have import() sub");
